pub struct PointerEnter { /* private fields */ }Expand description
Pointer is moved into boundaries of an element
This may also be as a result of a pointer being pressed on a device that does not support hover
Implementations
Sourceimpl PointerEnter
impl PointerEnter
pub fn new(pointer: PointerProperties, modifiers: Modifiers) -> Self
Sourcepub fn pointer(&self) -> &PointerProperties
pub fn pointer(&self) -> &PointerProperties
The properties of the pointer at the time of the event