pub struct PointerMove { /* private fields */ }Expand description
Pointer changes any properties that don’t fire PointerDown or PointerUp events.
This includes any changes to coordinates, pressure, tangential pressure, tilt, twist, dimensions or pressing/releasing buttons while another button is held.
Implementations
Sourceimpl PointerMove
impl PointerMove
pub fn new(pointer: PointerProperties, modifiers: Modifiers) -> Self
Sourcepub fn pointer(&self) -> &PointerProperties
pub fn pointer(&self) -> &PointerProperties
The properties of the pointer at the time of the event