pub struct PointerUp { /* private fields */ }Expand description
Last held pointer button is released
For mouse, this is when the device transitions from at least one button depressed to no buttons depressed. For touch, this is when physical contact is removed.
Implementations
Sourceimpl PointerUp
impl PointerUp
pub fn new( pointer: PointerProperties, modifiers: Modifiers, button_released: PointerButton, click_count: i64, ) -> Self
Sourcepub fn pointer(&self) -> &PointerProperties
pub fn pointer(&self) -> &PointerProperties
The properties of the pointer at the time of the event
The button which triggered this event
Sourcepub fn click_count(&self) -> i64
pub fn click_count(&self) -> i64
The number of consecutive presses, including this one
For example, if a mouse is only pressed&released once, click_count will be 1.